@@ -42,7 +42,6 @@ class ZoneDataTemplate(confuse.Template):
 
 ABB_RCF_CONF_TEMPLATE = {
     "log_dir": confuse.Filename(),
-    "pick_conf": confuse.Path(),
     "run_data_path": confuse.Template(),  # Already type checked by argparse
     "publish_tf_xform": bool,
     "edit_sequence": confuse.TypeTemplate(bool, default=False),
@@ -67,15 +66,16 @@ ABB_RCF_CONF_TEMPLATE = {
                 "accel": float,
                 "accel_ramp": float,
             },
-            "speed": {"precise": float, "travel": float},
+            "speed": {"pick_place": float, "travel": float},
             "zone": {
                 "pick": ZoneDataTemplate(),
                 "place": ZoneDataTemplate(),
                 "travel": ZoneDataTemplate(),
             },
-            "set_joint_pos": {
+            "joint_positions": {
                 "start": confuse.Sequence([float] * 6),
                 "end": confuse.Sequence([float] * 6),
+                "travel_trajectory": confuse.TypeTemplate(list, default=None),
             },
         },
     },
